Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(221)

Unified Diff: webrtc/api/objc/RTCIceCandidate+Private.h

Issue 1517253005: Update API for Objective-C RTCIceCandidate. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@updateRTCIceServer
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/api/objc/RTCIceCandidate+Private.h
diff --git a/webrtc/api/objc/RTCIceServer+Private.h b/webrtc/api/objc/RTCIceCandidate+Private.h
similarity index 51%
copy from webrtc/api/objc/RTCIceServer+Private.h
copy to webrtc/api/objc/RTCIceCandidate+Private.h
index 59f5a92dffa10d313b3cdf98c9e2ca0edc081f1a..ca79f01dafcaa5ba9134267cc6689f7dc620a34d 100644
--- a/webrtc/api/objc/RTCIceServer+Private.h
+++ b/webrtc/api/objc/RTCIceCandidate+Private.h
@@ -8,20 +8,26 @@
* be found in the AUTHORS file in the root of the source tree.
*/
-#import "RTCIceServer.h"
+#import "RTCIceCandidate.h"
-#include "talk/app/webrtc/peerconnectioninterface.h"
+#include "webrtc/base/scoped_ptr.h"
+#include "talk/app/webrtc/jsep.h"
NS_ASSUME_NONNULL_BEGIN
-@interface RTCIceServer ()
+@interface RTCIceCandidate ()
/**
* IceServer struct representation of this RTCIceServer object's data.
* This is needed to pass to the underlying C++ APIs.
*/
@property(nonatomic, readonly)
- webrtc::PeerConnectionInterface::IceServer iceServer;
+ rtc::scoped_ptr<webrtc::IceCandidateInterface> candidate;
tkchin_webrtc 2015/12/15 01:55:44 nit: let's give the C++ a "native" prefix so call
hjon 2015/12/15 17:35:44 Done.
+
+/**
+ * Initialize an RTCIceCandidate from a native IceCandidateInterface.
tkchin_webrtc 2015/12/15 01:55:44 add that no ownership is taken
hjon 2015/12/15 17:35:44 Done.
+ */
+- (instancetype)initWithCandidate:(webrtc::IceCandidateInterface *)candidate;
@end

Powered by Google App Engine
This is Rietveld 408576698
@@ -8,20 +8,26 @@
/**
- * IceServer struct representation of this RTCIceServer object's data.
- * This is needed to pass to the underlying C++ APIs.
+ * The native IceCandidateInterface representation of this RTCIceCandidate
+ * object. This is needed to pass to the underlying C++ APIs.
*/